#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 th-compat
version:              0.1.7
visibility:           public
id:                   th-compat-0.1.7-5y2cH3Get4yZqtKDB6qQT
key:                  th-compat-0.1.7-5y2cH3Get4yZqtKDB6qQT
license:              BSD-3-Clause
copyright:            (C) 2020 Ryan Scott
maintainer:           Ryan Scott <ryan.gl.scott@gmail.com>
author:               Ryan Scott
homepage:             https://github.com/haskell-compat/th-compat
synopsis:             Backward- (and forward-)compatible Quote and Code types
description:
    This package defines a "Language.Haskell.TH.Syntax.Compat"
    module, which backports the @Quote@ and @Code@ types to
    work across a wide range of @template-haskell@ versions.
    The @makeRelativeToProject@ utility is also backported.
    On recent versions of @template-haskell@ (2.17.0.0 or
    later), this module simply reexports definitions
    from "Language.Haskell.TH.Syntax". Refer to the Haddocks
    for "Language.Haskell.TH.Syntax.Compat" for examples of
    how to use this module.

category:             Text
abi:                  119724e69bfb86177b15373447c9ec05
exposed:              True
exposed-modules:      Language.Haskell.TH.Syntax.Compat
import-dirs:          /usr/lib/ghc-9.6.6/site-local/th-compat-0.1.7
library-dirs:         /usr/lib/ghc-9.6.6/site-local/th-compat-0.1.7
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/th-compat-0.1.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-th-compat
hs-libraries:         HSth-compat-0.1.7-5y2cH3Get4yZqtKDB6qQT
depends:              base-4.18.2.1 template-haskell-2.20.0.0
haddock-interfaces:   /usr/share/doc/haskell-th-compat/html/th-compat.haddock
haddock-html:         /usr/share/doc/haskell-th-compat/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

